% --------------------------------------------------------------------------
% the ELEMENTS package
% 
%   retrieve different properties of chemical elements
% 
% --------------------------------------------------------------------------
% Clemens Niederberger
% Web:    https://github.com/cgnieder/elements/
% E-Mail: contact@mychemistry.eu
% --------------------------------------------------------------------------
% Copyright 2011--2022 Clemens Niederberger
% 
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.
% 
% This work has the LPPL maintenance status `maintained'.
% 
% The Current Maintainer of this work is Clemens Niederberger.
% --------------------------------------------------------------------------
\DeclareAtomName[Hidrogeno]{1}{Hidr\'ogeno}
\DeclareAtomName{2}{Helio}
\DeclareAtomName{3}{Litio}
\DeclareAtomName{4}{Berilio}
\DeclareAtomName{5}{Boro}
\DeclareAtomName{6}{Carbono}
\DeclareAtomName[Nitrogeno]{7}{Nitr\'ogeno}
\DeclareAtomName[Oxigeno]{8}{Ox\'\i geno}
\DeclareAtomName[Fluor]{9}{Fl\'uor}
\DeclareAtomName[Neon]{10}{Ne\'on}
\DeclareAtomName{11}{Sodio}
\DeclareAtomName{12}{Magnesio}
\DeclareAtomName{13}{Aluminio}
\DeclareAtomName{14}{Silicio}
\DeclareAtomName[Fosforo]{15}{F\'osforo}
\DeclareAtomName{16}{Azufre}
\DeclareAtomName{17}{Cloro}
\DeclareAtomName[Argon]{18}{Arg\'on}
\DeclareAtomName{19}{Potasio}
\DeclareAtomName{20}{Calcio}
\DeclareAtomName{21}{Escandio}
\DeclareAtomName{22}{Titanio}
\DeclareAtomName{23}{Vanadio}
\DeclareAtomName{24}{Cromo}
\DeclareAtomName{25}{Manganeso}
\DeclareAtomName{26}{Hierro}
\DeclareAtomName{27}{Cobalto}
\DeclareAtomName[Niquel]{28}{N\'\i quel}
\DeclareAtomName{29}{Cobre}
\DeclareAtomName{30}{Zinc}
\DeclareAtomName{31}{Galio}
\DeclareAtomName{32}{Germanio}
\DeclareAtomName[Arsenico]{33}{Ars\'enico}
\DeclareAtomName{34}{Selenio}
\DeclareAtomName{35}{Bromo}
\DeclareAtomName[Kripton]{36}{Kript\'on}
\DeclareAtomName{37}{Rubidio}
\DeclareAtomName{38}{Estroncio}
\DeclareAtomName{39}{Itrio}
\DeclareAtomName{40}{Zirconio}
\DeclareAtomName{41}{Niobio}
\DeclareAtomName{42}{Molibdeno}
\DeclareAtomName{43}{Tecnecio}
\DeclareAtomName{44}{Rutenio}
\DeclareAtomName{45}{Rodio}
\DeclareAtomName{46}{Paladio}
\DeclareAtomName{47}{Plata}
\DeclareAtomName{48}{Cadmio}
\DeclareAtomName{49}{Indio}
\DeclareAtomName[Estano]{50}{Esta\~no}
\DeclareAtomName{51}{Antimonio}
\DeclareAtomName{52}{Telurio}
\DeclareAtomName{53}{Yodo}
\DeclareAtomName[Xenon]{54}{Xen\'on}
\DeclareAtomName{55}{Cesio}
\DeclareAtomName{56}{Bario}
\DeclareAtomName{57}{Lantano}
\DeclareAtomName{58}{Cerio}
\DeclareAtomName{59}{Praseodimio}
\DeclareAtomName{60}{Neodimio}
\DeclareAtomName{61}{Prometio}
\DeclareAtomName{62}{Samario}
\DeclareAtomName{63}{Europio}
\DeclareAtomName{64}{Gadolinio}
\DeclareAtomName{65}{Terbio}
\DeclareAtomName{66}{Disprosio}
\DeclareAtomName{67}{Holmio}
\DeclareAtomName{68}{Erbio}
\DeclareAtomName{69}{Tulio}
\DeclareAtomName{70}{Iterbio}
\DeclareAtomName{71}{Lutecio}
\DeclareAtomName{72}{Hafnio}
\DeclareAtomName{73}{Tantalo}
\DeclareAtomName{74}{Tungsteno}
\DeclareAtomName{75}{Renio}
\DeclareAtomName{76}{Osmio}
\DeclareAtomName{77}{Iridio}
\DeclareAtomName{78}{Platino}
\DeclareAtomName{79}{Oro}
\DeclareAtomName{80}{Mercurio}
\DeclareAtomName{81}{Talio}
\DeclareAtomName{82}{Plomo}
\DeclareAtomName{83}{Bismuto}
\DeclareAtomName{84}{Polonio}
\DeclareAtomName{85}{Astato}
\DeclareAtomName[Radon]{86}{Rad\'on}
\DeclareAtomName{87}{Francio}
\DeclareAtomName{88}{Radio}
\DeclareAtomName{89}{Actinio}
\DeclareAtomName{90}{Torio}
\DeclareAtomName{91}{Protactinio}
\DeclareAtomName{92}{Uranio}
\DeclareAtomName{93}{Neptunio}
\DeclareAtomName{94}{Plutonio}
\DeclareAtomName{95}{Americio}
\DeclareAtomName{96}{Curio}
\DeclareAtomName{97}{Berkelio}
\DeclareAtomName{98}{Californio}
\DeclareAtomName{99}{Einstenio}
\DeclareAtomName{100}{Fermio}
\DeclareAtomName{101}{Mendelevio}
\DeclareAtomName{102}{Nobelio}
\DeclareAtomName{103}{Laurencio}
\DeclareAtomName{104}{Rutherfordio}
\DeclareAtomName{105}{Dubnio}
\DeclareAtomName{106}{Seaborgio}
\DeclareAtomName{107}{Bohrio}
\DeclareAtomName{108}{Hassio}
\DeclareAtomName{109}{Meitnerio}
\DeclareAtomName{110}{Darmstadtio}
\DeclareAtomName{111}{Roentgenio}
\DeclareAtomName{112}{Copernicio}
\DeclareAtomName{113}{Nihonio}
\DeclareAtomName{114}{Flerovio}
\DeclareAtomName{115}{Moscovio}
\DeclareAtomName{116}{Livermorio}
\DeclareAtomName{117}{Tenese}
\DeclareAtomName[Oganesson]{118}{Oganess\'on}

\endinput
