% --------------------------------------------------------------------------
% the ELEMENTS package
% 
%   retrieve different properties of chemical elements
% 
% --------------------------------------------------------------------------
% Clemens Niederberger
% Web:    https://github.com/cgnieder/elements/
% E-Mail: contact@mychemistry.eu
% --------------------------------------------------------------------------
% Copyright 2011--2022 Clemens Niederberger
% 
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.
% 
% This work has the LPPL maintenance status `maintained'.
% 
% The Current Maintainer of this work is Clemens Niederberger.
% --------------------------------------------------------------------------
\DeclareAtomName[Hydrogene]{1}{Hydrog\`ene}
\DeclareAtomName[Helium]{2}{H\'elium}
\DeclareAtomName{3}{Lithium}
\DeclareAtomName[Beryllium]{4}{B\'eryllium}
\DeclareAtomName{5}{Bore}
\DeclareAtomName{6}{Carbone}
\DeclareAtomName{7}{Azote}
\DeclareAtomName[Oxygene]{8}{Oxyg\`ene}
\DeclareAtomName{9}{Fluor}
\DeclareAtomName[Neon]{10}{N\'eon}
\DeclareAtomName{11}{Sodium}
\DeclareAtomName[Magnesium]{12}{Magn\'esium}
\DeclareAtomName{13}{Aluminium}
\DeclareAtomName{14}{Silicium}
\DeclareAtomName{15}{Phosphore}
\DeclareAtomName{16}{Soufre}
\DeclareAtomName{17}{Chlore}
\DeclareAtomName{18}{Argon}
\DeclareAtomName{19}{Potassium}
\DeclareAtomName{20}{Calcium}
\DeclareAtomName{21}{Scandium}
\DeclareAtomName{22}{Titane}
\DeclareAtomName{23}{Vanadium}
\DeclareAtomName{24}{Chrome}
\DeclareAtomName[Manganese]{25}{Mangan\`ese}
\DeclareAtomName{26}{Fer}
\DeclareAtomName{27}{Cobalt}
\DeclareAtomName{28}{Nickel}
\DeclareAtomName{29}{Cuivre}
\DeclareAtomName{30}{Zinc}
\DeclareAtomName{31}{Gallium}
\DeclareAtomName{32}{Germanium}
\DeclareAtomName{33}{Arsenic}
\DeclareAtomName[Selenium]{34}{S\'el\'enium}
\DeclareAtomName{35}{Brome}
\DeclareAtomName{36}{Krypton}
\DeclareAtomName{37}{Rubidium}
\DeclareAtomName{38}{Strontium}
\DeclareAtomName{39}{Yttrium}
\DeclareAtomName{40}{Zirconium}
\DeclareAtomName{41}{Niobium}
\DeclareAtomName[Molybdene]{42}{Molybd\`ene}
\DeclareAtomName[Technetium]{43}{Techn\'etium}
\DeclareAtomName[Ruthenium]{44}{Ruth\'enium}
\DeclareAtomName{45}{Rhodium}
\DeclareAtomName{46}{Palladium}
\DeclareAtomName{47}{Argent}
\DeclareAtomName{48}{Cadmium}
\DeclareAtomName{49}{Indium}
\DeclareAtomName{50}{Etain}
\DeclareAtomName{51}{Antimoine}
\DeclareAtomName{52}{Tellure}
\DeclareAtomName{53}{Iode}
\DeclareAtomName[Xenon]{54}{X\'enon}
\DeclareAtomName[Cesium]{55}{C\'esium}
\DeclareAtomName{56}{Baryum}
\DeclareAtomName{57}{Lanthane}
\DeclareAtomName[Cerium]{58}{C\'erium}
\DeclareAtomName[Praseodyme]{59}{Pras\'eodyme}
\DeclareAtomName[Neodyme]{60}{N\'eodyme}
\DeclareAtomName[Promethium]{61}{Prom\'ethium}
\DeclareAtomName{62}{Samarium}
\DeclareAtomName{63}{Europium}
\DeclareAtomName{64}{Gadolinium}
\DeclareAtomName{65}{Terbium}
\DeclareAtomName{66}{Dysprosium}
\DeclareAtomName{67}{Holmium}
\DeclareAtomName{68}{Erbium}
\DeclareAtomName{69}{Thulium}
\DeclareAtomName{70}{Ytterbium}
\DeclareAtomName[Lutecium]{71}{Lut\'ecium}
\DeclareAtomName{72}{Hafnium}
\DeclareAtomName{73}{Tantale}
\DeclareAtomName[Tungstene]{74}{Tungst\`ene}
\DeclareAtomName[Rhenium]{75}{Rh\'enium}
\DeclareAtomName{76}{Osmium}
\DeclareAtomName{77}{Iridium}
\DeclareAtomName{78}{Platine}
\DeclareAtomName{79}{Or}
\DeclareAtomName{80}{Mercure}
\DeclareAtomName{81}{Thallium}
\DeclareAtomName{82}{Plomb}
\DeclareAtomName{83}{Bismuth}
\DeclareAtomName{84}{Polonium}
\DeclareAtomName{85}{Astate}
\DeclareAtomName{86}{Radon}
\DeclareAtomName{87}{Francium}
\DeclareAtomName{88}{Radium}
\DeclareAtomName{89}{Actinium}
\DeclareAtomName{90}{Thorium}
\DeclareAtomName{91}{Protactinium}
\DeclareAtomName{92}{Uranium}
\DeclareAtomName{93}{Neptunium}
\DeclareAtomName{94}{Plutonium}
\DeclareAtomName[Americium]{95}{Am\'ericium}
\DeclareAtomName{96}{Curium}
\DeclareAtomName[Berkelium]{97}{Berk\'elium}
\DeclareAtomName{98}{Californium}
\DeclareAtomName{99}{Einsteinium}
\DeclareAtomName{100}{Fermium}
\DeclareAtomName[Mendelevium]{101}{Mendel\'evium}
\DeclareAtomName[Nobelium]{102}{Nob\'elium}
\DeclareAtomName{103}{Lawrencium}
\DeclareAtomName{104}{Rutherfordium}
\DeclareAtomName{105}{Dubnium}
\DeclareAtomName{106}{Seaborgium}
\DeclareAtomName{107}{Bohrium}
\DeclareAtomName{108}{Hassium}
\DeclareAtomName{109}{Meitnerium}
\DeclareAtomName{110}{Darmstadtium}
\DeclareAtomName{111}{Roentgenium}
\DeclareAtomName{112}{Copernicium}
\DeclareAtomName{113}{Nihonium}
\DeclareAtomName[Flerovium]{114}{Fl\'erovium}
\DeclareAtomName{115}{Moscovium}
\DeclareAtomName{116}{Livermorium}
\DeclareAtomName{117}{Tennesse}
\DeclareAtomName{118}{Oganesson}

\endinput
